##Local Requirements
PHP 5.5 or greater
Composer https://getcomposer.org/download/

##Steps
Run

```composer install```

After the composer packages are installed, now run phpunit

```vendor/bin/phpunit```

##Part 1
You will be writing the /src/TriNetAssess/OAuth2FlowAsses.php class using Test Driven Development (TDD) with the tests already created for you. We chose to have you implement a library that we use, Guzzle. We also included the classes you will require to complete this portion of the test.

For Guzzle Documentation please visit: http://docs.guzzlephp.org/en/latest/

1. Unit tests for this part are located in /tests/TriNetAssess/OAuth2FlowAssessTest.  Do Not Alter OAuth2FlowAssessTest.php.

2. Write code in /src/TriNetAssess/OAuth2FlowAsses.php so that all unit tests pass.

##Part 2
For Part 2 we would like you to write your own tests and classes from scratch. Add whatever code is needed to this project to complete. Minimum you should produce is a Company Class that can perform the below tasks, although multiple classes can be used to follow best OO principles. For simplicity, please do not use any database storage. Assume an external piece will handle data persistence.  

We expect 100% code coverage on unit tests.  Please read all details before beginning, how you implement is completely up to you.

Consider the following objects and their relationships.

- A Company can have as many Apps as desired.

- A Bundle is a collection of Apps and can have as many as desired.

- When a Bundle is applied to a Company, all Apps within that Bundle are applied to that Company.

- When a Bundle is applied to a Company, any existing Apps that are not in the Bundle remain applied to that Company. 

- After a Bundle is applied to a Company, any App that is not in the Bundle can still be applied to that Company.

- Each App costs the Company a different price on a monthly basis.

Consider this sample data when writing your unit tests:

- Company A owns App 1 and App 2

- Company B owns App 2 and App 3

- Company C owns App 1

- Bundle X contains App 2 and App 3

- App 1 monthly cost is $1

- App 2 monthly cost is $2

- App 3 monthly cost is $3


Your class(es) should have the following interface behaviors (assert with UT).  Additionally, general error handling and input sanitation should be handled:

- Retrieve a Company's total monthly cost.

- Calculate a Company's annual cost.

- Add all Apps within a Bundle to Company with no Apps.

- Add all Apps within a Bundle to Company with existing Apps.

- Add an App to a Company after a Bundle has been provided.

- Ensure no duplicate Apps are owned after adding to a Bundle or at any time.
