<?php
namespace TriNetAssess;

class Company {
  // NOTE: I will not bother with all getters and setters
  public $id;
  public $name;
  protected $appMap; // appId->app map
  // NOTE: I used an ID map instead of a set because I assume
  // the persistent storage is not in memory so pointers are
  // not dependable identifies
  
  function __construct($id, $name, array $apps = []) {
      $this->id   = $id;
      $this->name = $name;
      // NOTE: not bothering with input checking - would normally be covered
      // by the OEM/model defintion/schema
      
      $this->appMap = [];
      foreach ($apps as $app) {
        $this->addApp($app);
      }
  }
  
  // gets the Company's apps
  function getApps() {
    return array_values($this->appMap);
  }
  
  // adds the given app to the Company
  function addApp(App $app) {
    $this->appMap[$app->id] = $app;
  }
  
  // adds all apps from the given Bundle to the Company
  function addBundle(Bundle $bundle) {
    foreach ($bundle->apps as $app) {
      $this->addApp($app);
    }
  }
  
  // gets the monthly cost of the Company in cents
  function getMonthlyCostCents() {
    // sum the monthly costs of all apps in the company
    $monthlyCostCents = 0;
    foreach ($this->appMap as $appId=>$app) {
      $monthlyCostCents += $app->monthlyCostCents;
    }
    
    return $monthlyCostCents;
  }
  
  // gets the anual cost of the Company in cents
  function getAnualCostCents() {
    // cost/month * 12 months/year = cost/year
    $anualCostCents = $this->getMonthlyCostCents() * 12;
    return $anualCostCents;
  }
}